BytesSplitter class

Split stream into IRC message chunk

Inheritance

Constructors

BytesSplitter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<Uint8List> stream) → Stream<Uint8List>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Uint8List input) → Uint8List
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<Uint8List, TT> other) → Converter<Uint8List, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<Uint8List> sink) → Sink<Uint8List>
Starts a chunked conversion.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited