Channel class

Constructors

Channel({required String name, String? key})

Properties

clients → List<Client>
no setter
flags → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
key ↔ String?
getter/setter pair
members → Iterable<String>
no setter
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic ↔ String?
getter/setter pair

Methods

add(Client user, {String? key}) → bool
broadcast(List<int> data, {required Client from, bool echo = true}) → void
isFlagOn(String ch) → bool
isOnChannel({required Client client}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Client user) → void
sendChannelInfo({required Client to}) → void
setFlag(String ch, {required bool on}) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited