Client class

The chat client that connects to this server.

Constructors

Client({required ChatServer chatServer, required Socket socket, required Encoding encoding})

Properties

awayMsg → String?
no setter
cloakHost → String
final
hashCode → int
The hash code for this object.
no setterinherited
nick → String
no setter
registered → bool
no setter
remoteAddress → InternetAddress
final
remotePort → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept({required void onDone(), required void onError(dynamic error, dynamic stackTrace)}) → StreamSubscription<Message>
add(Channel channel) → void
checkConnectionActivity(DateTime time) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printNumeric(NumericReply n) → String
remove(Channel channel) → void
sendEndOfMotd() → void
sendMotdStart() → void
sendNumeric(NumericReply n) → void
sendNumericWith(NumericReply n, List<String> params, {String? text}) → void
sendRawData(List<int> data) → void
sendRawString(String text) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited