Message class

Constructors

Message({String? prefix, required String command, required List<String> params})
Message.parse(List<String> rowMessage)
factory

Properties

command → String
final
hashCode → int
The hash code for this object.
no setterinherited
params → List<String>
final
prefix → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encodeNumeric(String from, String to, NumericReply n, Encoding encoding) → List<int>
encodeNumericWith(String from, String to, NumericReply n, List<String> params, Encoding encoding, {String? text}) → List<int>
isValidAsChannelName(String input) → bool
isValidAsChanstring(String input, {int start = 1}) → bool
isValidAsNickname(String input) → bool
isValidAsUserName(String input) → bool
printNumeric(NumericReply n) → String