ServerConfig class

Constructors

ServerConfig({required ConnectionAuth connectionAuth, String? motdPath})
ServerConfig.withEnvironment({ConnectionAuth? connectionAuth, String? motdPath})
ServerConfig.withFixedPassword(String password, {String? motdPath})

Properties

connectionAuth → ConnectionAuth
final
hashCode → int
The hash code for this object.
no setterinherited
motdPath → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited