SocketConfig class

Constructors

SocketConfig({required InternetAddress address, required int port, required int connectionCheckIntervalSeconds, required String? privateKeyPath})
SocketConfig.withEnvironment({InternetAddress? address, int? port, int? connectionCheckIntervalSeconds, String? privateKeyPath})

Properties

address → InternetAddress
final
connectionCheckIntervalSeconds → int
final
hashCode → int
The hash code for this object.
no setterinherited
port → int
final
privateKeyPath → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited